<?php
/** @var $gmDB
 * @var  $gmCore
 * @var  $gmGallery
 * @var  $id
 * @var  $query
 * @var  $module
 * @var  $settings
 * @var  $term
 * @var  $is_bot
 * @var  $shortcode_raw
 **/

global $wp;
$settings      = array_merge( $settings, array(
	'ID'        => $id,
	'url'       => remove_query_arg( 'gm' . $id . '_slide', add_query_arg( $_SERVER['QUERY_STRING'], '', home_url( $wp->request ) ) ),
	'moduleUrl' => $module['url'],
) );
$iSlide        = $settings['initial_slide'] = (int) $gmCore->_get( 'gm' . $id . '_slide', 0 );
$base_url_host = parse_url( $gmCore->upload['url'], PHP_URL_HOST );
$term_url      = remove_query_arg( 'gm' . $id, $settings['url'] );

$allsettings = array_merge( $module['options'], $settings );
$gmedias     = $gmDB->get_gmedias( $query );

$content = array(
	'data'  => array(),
	'terms' => array(),
);

foreach ( $gmedias as $item ) {
	$type = explode( '/', $item->mime_type );

	$_meta    = $gmDB->get_metadata( 'gmedia', $item->ID );
	$metadata = $_meta['_metadata'][0];
	$meta     = array(
		'width'  => empty( $metadata['web']['width'] ) ? ( empty( $metadata['width'] ) ? null : $metadata['width'] ) : $metadata['web']['width'],
		'height' => empty( $metadata['web']['height'] ) ? ( empty( $metadata['height'] ) ? null : $metadata['height'] ) : $metadata['web']['height'],
		'views'  => empty( $_meta['views'][0] ) ? 0 : (int) $_meta['views'][0],
		'likes'  => empty( $_meta['likes'][0] ) ? 0 : (int) $_meta['likes'][0],
	);

	$author['name']       = get_the_author_meta( 'display_name', $item->author );
	$author['posts_link'] = get_author_posts_url( $item->author );
	if ( ! empty( $allsettings['show_author_avatar'] ) ) {
		$avatar_img = get_avatar( $item->author, 60 );
		if ( preg_match( "/src=['\"](.*?)['\"]/i", $avatar_img, $matches ) ) {
			$author['avatar'] = $matches[1];
		}
	}
	$alttext = ! empty( $_meta['_image_alt'][0] ) ? $_meta['_image_alt'][0] : $item->title;

	$content['data'][ $item->ID ] = array(
		'id'     => $item->ID,
		'type'   => $type[0],
		'file'   => $item->gmuid,
		'meta'   => $meta,
		'title'  => $item->title,
		'alt'    => $alttext,
		'author' => $author,
	);

	if ( ! empty( $allsettings['show_description'] ) ) {
		$content['data'][ $item->ID ]['description'] = str_replace( array( "\r\n", "\r", "\n" ), '', wpautop( $item->description ) );
	}

	if ( ! empty( $item->post_id ) ) {
		$content['data'][ $item->ID ]['post_link'] = get_permalink( $item->post_id );
	}
	if ( ! empty( $allsettings['show_share_button'] ) ) {
		if ( empty( $item->post_id ) ) {
			$content['data'][ $item->ID ]['post_link'] = $gmCore->gmcloudlink( $item->ID, 'single' );
		}
	}
	if ( ! empty( $allsettings['show_comments'] ) ) {
		if ( ! empty( $item->post_id ) ) {
			$cc                                 = wp_count_comments( $item->post_id );
			$content['data'][ $item->ID ]['cc'] = $cc->approved;
		} else {
			$content['data'][ $item->ID ]['cc'] = '';
		}
	}

	if ( ! empty( $allsettings['show_link_button'] ) ) {
		$content['data'][ $item->ID ]['link'] = $item->link;
		$link_target                          = '';
		if ( $item->link ) {
			$url_host = parse_url( $item->link, PHP_URL_HOST );
			if ( $url_host == $base_url_host || empty( $url_host ) ) {
				$link_target = '_self';
			} else {
				$link_target = '_blank';
			}
		}
		if ( isset( $_meta['link_target'][0] ) ) {
			$link_target = $_meta['link_target'][0];
		}
		$content['data'][ $item->ID ]['link_target'] = $link_target;
	}

	if ( ! empty( $allsettings['show_download_button'] ) ) {
		$download = '';
		if ( ! empty( $_meta['download'][0] ) ) {
			$download = $_meta['download'][0];
		} else {
			if ( 'image' == $type[0] ) {
				$download = $gmCore->gm_get_media_image( $item->ID, 'original' );
			} else {
				$download = "{$gmCore->upload['url']}/{$gmGallery->options['folder'][$type[0]]}/{$item->gmuid}";
			}
		}
		$content['data'][ $item->ID ]['download'] = $download;
	}

	$exif = $gmCore->metadata_info( $item->ID );

	if ( ! empty( $allsettings['show_details_tab'] ) ) {
		$details = array();
		if ( ! empty( $exif ) ) {
			$details['model']           = empty( $exif['model'] ) ? '' : $exif['model']['value'];
			$details['lens']            = empty( $exif['lens'] ) ? '' : $exif['lens']['value'];
			$details['camera_settings'] = array(
				'focallength' => empty( $exif['focallength'] ) ? ( empty( $exif['focallength35'] ) ? '' : $exif['focallength35']['value'] ) : $exif['focallength']['value'],
				'aperture'    => empty( $exif['aperture'] ) ? '' : str_replace( 'f', 'ƒ', $exif['aperture']['value'] ),
				'exposure'    => empty( $exif['exposure'] ) ? '' : $exif['exposure']['value'],
				'iso'         => empty( $exif['iso'] ) ? '' : 'ISO ' . $exif['iso']['value'],
			);
			$details['camera_settings'] = array_filter( $details['camera_settings'] );
			$details['taken']           = empty( $exif['created_timestamp'] ) ? '' : date_i18n( get_option( 'date_format' ), $exif['created_timestamp']['value'] );
		}
		$details['uploaded']                     = date_i18n( get_option( 'date_format' ), strtotime( $item->date ) );
		$content['data'][ $item->ID ]['details'] = $details;
	}

	if ( ! empty( $allsettings['show_location_tab'] ) ) {
		$gps_location = array();
		if ( ! empty( $_meta['_gps'][0] ) ) {
			$gps_location = $_meta['_gps'][0];
		} elseif ( ! empty( $exif['GPS'] ) ) {
			$gps_location = $exif['GPS']['value'];
		}
		$content['data'][ $item->ID ]['location'] = implode( ',', $gps_location );
	}


	if ( ! empty( $allsettings['show_tags'] ) ) {
		$content['data'][ $item->ID ]['tags'] = array();
		if ( ( $terms = $gmDB->get_the_gmedia_terms( $item->ID, 'gmedia_tag' ) ) ) {
			foreach ( $terms as $_term ) {
				$content['data'][ $item->ID ]['tags'][]      = $_term->term_id;
				$content['terms']['tags'][ $_term->term_id ] = array(
					'name' => $_term->name,
					'url'  => add_query_arg( array( "gm{$id}" => array( 'tag__in' => $_term->term_id ) ), $term_url ),
				);
			}
		}
	}
	if ( ! empty( $allsettings['show_album'] ) ) {
		$content['data'][ $item->ID ]['albums'] = array();
		if ( ( $terms = $gmDB->get_the_gmedia_terms( $item->ID, 'gmedia_album' ) ) ) {
			foreach ( $terms as $_term ) {
				$content['data'][ $item->ID ]['albums'][]      = $_term->term_id;
				$content['terms']['albums'][ $_term->term_id ] = array(
					'name' => $_term->name,
					'url'  => add_query_arg( array( "gm{$id}" => array( 'album__in' => $_term->term_id ) ), $term_url ),
				);
			}
		}
	}
	if ( ! empty( $allsettings['show_category'] ) ) {
		$content['data'][ $item->ID ]['categories'] = array();
		if ( ( $terms = $gmDB->get_the_gmedia_terms( $item->ID, 'gmedia_category' ) ) ) {
			foreach ( $terms as $_term ) {
				$content['data'][ $item->ID ]['categories'][]      = $_term->term_id;
				$content['terms']['categories'][ $_term->term_id ] = array(
					'name' => $_term->name,
					'url'  => add_query_arg( array( "gm{$id}" => array( 'category__in' => $_term->term_id ) ), $term_url ),
				);
			}
		}
	}
}


if ( empty( $content['data'] ) ) {
	echo GMEDIA_GALLERY_EMPTY;

	return;
}

$slides        = array();
$slides_thumbs = array();
$i             = 0;
foreach ( $content['data'] as $item_id => $item ) {
	$i ++;
	$web   = $gmCore->gm_get_media_image( $item['id'], 'web' );
	$thumb = $gmCore->gm_get_media_image( $item['id'], 'thumb' );
	if ( ! empty( $item['meta']['width'] ) && ! empty( $item['meta']['height'] ) ) {
		$ratio = $item['meta']['width'] / $item['meta']['height'];
	} else {
		if ( strpos( $thumb, '/assets/' ) ) {
			$ratio = 1;
		} else {
			$ratio = 1.5;
		}
	}
	$content['data'][ $item_id ]['ratio'] = $ratio;
	if ( 1 <= $ratio ) {
		$orientation = 'gmpmp_photo_landscape';
	} else {
		$orientation = 'gmpmp_photo_portrait';
	}
	$img_src   = '';
	$thumb_src = '';
	if ( $is_bot || 1 === $i ) {
		$img_src   = 'src="' . $web . '"';
		$thumb_src = 'src="' . $thumb . '"';
	}
	$img_class     = '';
	$img_preloader = '';
	if ( ! $is_bot ) {
		$img_class     .= ' swiper-lazy';
		$img_preloader = '<div class="swiper-lazy-preloader swiper-lazy-preloader-black"></div>';
	}
	$slides[]        = '
		<div class="swiper-slide" data-hash="gmedia' . $item['id'] . '" data-photo-id="' . $item['id'] . '"><span class="gmpmp_va"></span>' . '<img ' . $img_src . ' data-src="' . $web . '" alt="' . esc_attr( $item['alt'] ) . '" data-protect="' . $item['author']['name'] . '" class="gmpmp_the_photo' . $img_class . '">' . $img_preloader . '</div>';
	$slides_thumbs[] = '
		<div class="swiper-slide gmpmp_photo" data-photo-id="' . $item['id'] . '">' . '<img ' . $thumb_src . ' data-src="' . $thumb . '" alt="' . esc_attr( $item['alt'] ) . '" class="gmpmp_photo swiper-lazy ' . $orientation . '">' . '<span class="swiper-lazy-preloader swiper-lazy-preloader-black"></span>' . '</div>';
}
$content['data'] = array_values( $content['data'] );

$photo_show_class = '';
if ( ! empty( $allsettings['gallery_maximized'] ) ) {
	$photo_show_class .= ' gmpmp_maximized';
}
if ( ! empty( $allsettings['gallery_focus'] ) ) {
	$photo_show_class .= ' gmpmp_focus';
}
if ( ! empty( $allsettings['gallery_focus_maximized'] ) ) {
	$photo_show_class .= ' gmpmp_focus_maximized';
}
if ( empty( $allsettings['keyboard_help'] ) ) {
	$photo_show_class .= ' gmpmp_diskeys';
}
if ( ! $is_bot ) {
	$photo_show_class .= ' gmpmp_preload';
}
?>

	<div class="gmpmp_photo_show gmpmp_w960 gmpmp_w640 gmpmp_w480<?php echo $photo_show_class; ?>">

		<div class="gmpmp_photo_wrap has_prev_photo has_next_photo">
			<?php
			//if ( empty( $gmGallery->options['license_key'] ) ) {
			//	echo "<a class='gmlove' target='_blank' href='http://bit.ly/2snVAca'>" . __( 'Trial version - Get License', 'grand-media' ) . "</a>";
			//}
			?>
			<div class="swiper-container swiper-big-images">
				<div class="gmpmp_photo_arrow_next gmpmp_photo_arrow gmpmp_next">
					<div title="Next" class="gmpmp_arrow"></div>
				</div>
				<div class="gmpmp_photo_arrow_previous gmpmp_photo_arrow gmpmp_prev">
					<div title="Previous" class="gmpmp_arrow"></div>
				</div>
				<div class="swiper-wrapper">
					<?php
					echo implode( '', $slides );
					?>
				</div>
			</div>
		</div>

		<?php
		$gallery_info = array();
		if ( ! empty( $term ) ) {
			$gallery_info[] = $term;
		}
		$get_query = $gmCore->_get( "gm{$id}" );
		if ( ! empty( $get_query ) ) {
			$get_terms = array();
			foreach ( $get_query as $key => $val ) {
				if ( in_array( $key, array( 'tag__in', 'album__in', 'category__in' ) ) ) {
					$val_ids   = wp_parse_id_list( $val );
					$get_terms = array_filter( array_merge( $get_terms, $val_ids ) );
				}
			}
			if ( ! empty( $get_terms ) ) {
				$gallery_info = $gmDB->get_terms( array( 'gmedia_album', 'gmedia_category', 'gmedia_tag' ), array( 'include' => $get_terms ) );
			}
		}
		if ( ! empty( $gallery_info ) || ! empty( $content['terms']['categories'] ) || ! empty( $content['terms']['albums'] ) || ! empty( $content['terms']['tags'] ) ) {
			?>
			<div class="gmpmp_gallery_sources_menu gmpmp_menu_closed">
				<div class="gmpmp_menu_button"></div>
				<div class="gmpmp_menu_bg">
					<div class="gmpmp_menu_scroll">
						<div class="gmpmp_gallery_sources_list">
							<?php
							if ( ! empty( $gallery_info ) ) {
								foreach ( $gallery_info as $gallery_term ) {
									?>
									<div class="gmpmp_gallery_title"><?php echo $gallery_term->name; ?></div>
									<?php
									if ( ! empty( $gallery_term->description ) ) {
										echo '<div class="gmpmp_gallery_description">' . wpautop( $gallery_term->description ) . '</div>';
									}
								}
							}
							?>
							<div class="gmpmp_gallery_sources"><?php
								if ( ! empty( $content['terms']['categories'] ) ) {
									$list = array();
									foreach ( $content['terms']['categories'] as $term_id => $_term ) {
										$list[] = '<a href="' . urldecode( $_term['url'] ) . '">' . $_term['name'] . '</a>';
									}
									echo "<p><span class='gmpmp_categories_label'>{$allsettings['categories_text']}</span> " . implode( ', ', $list ) . '</p>';
								}
								if ( ! empty( $content['terms']['albums'] ) ) {
									$list = array();
									foreach ( $content['terms']['albums'] as $term_id => $_term ) {
										$list[] = '<a href="' . urldecode( $_term['url'] ) . '">' . $_term['name'] . '</a>';
									}
									echo "<p><span class='gmpmp_albums_label'>{$allsettings['albums_text']}</span> " . implode( ', ', $list ) . '</p>';
								}
								if ( ! empty( $content['terms']['tags'] ) ) {
									$list = array();
									foreach ( $content['terms']['tags'] as $term_id => $_term ) {
										$list[] = '<a href="' . urldecode( $_term['url'] ) . '">#' . $_term['name'] . '</a>';
									}
									echo "<p><span class='gmpmp_tags_label'>{$allsettings['tags_text']}</span> " . implode( ' ', $list ) . '</p>';
								}
								?></div>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
		?>

		<div class="gmpmp_photo_header">
			<div class="gmpmp_wrapper gmpmp_clearfix">
				<div class="gmpmp_focus_actions">
					<?php if ( ! empty( $allsettings['show_share_button'] ) ) { ?>
						<ul class="gmpmp_focus_share">
							<li style="list-style:none;" class="gmpmp_share_wrapper">
								<a class="gmpmp_button gmpmp_share"><?php _e( 'Share', 'grand-media' ); ?></a>
								<ul class="gmpmp_sharelizers gmpmp_clearfix">
									<li style="list-style:none;"><a class="gmpmp_button gmpmp_facebook gmpmp_sharelizer"><?php _e( 'Facebook', 'grand-media' ); ?></a></li>
									<li style="list-style:none;"><a class="gmpmp_button gmpmp_twitter gmpmp_sharelizer"><?php _e( 'Twitter', 'grand-media' ); ?></a></li>
									<li style="list-style:none;"><a class="gmpmp_button gmpmp_pinterest gmpmp_sharelizer"><?php _e( 'Pinterest', 'grand-media' ); ?></a></li>
									<li style="list-style:none;"><a class="gmpmp_button gmpmp_stumbleupon gmpmp_sharelizer"><?php _e( 'StumbleUpon', 'grand-media' ); ?></a></li>
								</ul>
							</li>
						</ul>
					<?php } ?>
					<?php if ( ! empty( $allsettings['enable_counters'] ) && ! empty( $allsettings['show_like_button'] ) ) { ?>
						<ul class="gmpmp_focus_like_fave gmpmp_clearfix">
							<li style="list-style:none;"><a class="gmpmp_button gmpmp_like"><?php _e( 'Like', 'grand-media' ); ?></a></li>
						</ul>
					<?php } ?>
					<ul class="gmpmp_focus_arrows gmpmp_clearfix">
						<li style="list-style:none;"><a class="gmpmp_button gmpmp_photo_arrow_previous gmpmp_prev"><?php _e( 'Previous', 'grand-media' ); ?></a></li>
						<li style="list-style:none;"><a class="gmpmp_button gmpmp_photo_arrow_next gmpmp_next"><?php _e( 'Next', 'grand-media' ); ?></a></li>
					</ul>
				</div>
				<div class="gmpmp_name_wrap gmpmp_clearfix<?php if ( empty( $allsettings['show_author_avatar'] ) ) {
					echo ' gmpmp_no_avatar';
				} ?>">
					<?php if ( ! empty( $allsettings['show_author_avatar'] ) ) { ?>
						<div class="gmpmp_user_avatar">
							<a class="gmpmp_user_avatar_link" href="<?php echo urldecode( $content['data'][ $iSlide ]['author']['posts_link'] ); ?>"><img src="<?php echo $content['data'][ $iSlide ]['author']['avatar']; ?>" alt=""/></a>
						</div>
					<?php } ?>
					<div class="gmpmp_title_author">
						<div class="gmpmp_title"><?php echo $content['data'][ $iSlide ]['title']; ?></div>

						<?php if ( ! empty( $allsettings['show_author_name'] ) ) { ?>
							<div class="gmpmp_author_name">
								<a class="gmpmp_author_link" href="<?php echo urldecode( $content['data'][ $iSlide ]['author']['posts_link'] ); ?>"><?php echo $content['data'][ $iSlide ]['author']['name']; ?></a>
							</div>
						<?php } ?>
						<?php if ( ! empty( $allsettings['show_category'] ) ) {
							$item_cats = array();
							if ( ! empty( $content['data'][ $iSlide ]['categories'] ) ) {
								foreach ( $content['data'][ $iSlide ]['categories'] as $term_id ) {
									$term_url    = urldecode( $content['terms']['categories'][ $term_id ]['url'] );
									$term_name   = $content['terms']['categories'][ $term_id ]['name'];
									$item_cats[] = "<a class=\"gmpmp_item_cat_link\" href=\"{$term_url}\">{$term_name}</a>";
								}
								$term_class = '';
							} else {
								$item_cats[] = "<a class=\"gmpmp_item_cat_link\" href=\"#\"></a>";
								$term_class  = ' gmpmp_hide';
							}
							?>
							<div class="gmpmp_item_cat<?php echo $term_class; ?>">
								<span class="gmpmp_category_label"><?php echo $allsettings['category_text']; ?></span><span class="gmpmp_categories"><?php echo implode( ', ', $item_cats ); ?></span>
							</div>
						<?php } ?>
						<?php if ( ! empty( $allsettings['show_album'] ) ) {
							if ( isset( $content['data'][ $iSlide ]['albums'][0] ) ) {
								$term_id    = $content['data'][ $iSlide ]['albums'][0];
								$term_url   = urldecode( $content['terms']['albums'][ $term_id ]['url'] );
								$term_name  = $content['terms']['albums'][ $term_id ]['name'];
								$term_class = '';
							} else {
								$term_url   = '#';
								$term_name  = '';
								$term_class = ' gmpmp_hide';
							} ?>
							<div class="gmpmp_item_alb<?php echo $term_class; ?>">
								<span class="gmpmp_album_label"><?php echo $allsettings['album_text']; ?></span><a class="gmpmp_item_alb_link" href="<?php echo $term_url; ?>"><?php echo $term_name; ?></a>
							</div>
						<?php } ?>
					</div>
				</div>
				<div class="gmpmp_actions gmpmp_clearfix">
					<div class="gmpmp_carousel gmpmp_has_previous gmpmp_has_next">
						<div class="gmpmp_previous_button"></div>
						<div class="gmpmp_photo_carousel">
							<div class="swiper-container swiper-small-images">
								<div class="swiper-wrapper">
									<?php echo implode( '', $slides_thumbs ); ?>
								</div>
							</div>
						</div>
						<div class="gmpmp_next_button"></div>
					</div>
					<?php
					$show_share_button = ! empty( $allsettings['show_share_button'] );
					$enable_counters   = ! empty( $allsettings['enable_counters'] );
					$show_like_button  = ! empty( $allsettings['show_like_button'] );
					if ( $show_share_button || ( $enable_counters && $show_like_button ) ) { ?>
						<div class="gmpmp_big_button_wrap<?php echo ( ! $show_share_button || ! $enable_counters || ! $show_like_button ) ? ' gmpmp_one_button' : ''; ?>">
							<?php if ( $show_share_button ) { ?>
								<div class="gmpmp_share_wrapper">
									<a class="gmpmp_button gmpmp_share"><?php _e( 'Share', 'grand-media' ); ?></a>

									<div class="gmpmp_sharelizers_wrap">
										<ul class="gmpmp_sharelizers">
											<li style="list-style:none;"><a class="gmpmp_button gmpmp_facebook gmpmp_sharelizer"><?php _e( 'Facebook', 'grand-media' ); ?></a></li>
											<li style="list-style:none;"><a class="gmpmp_button gmpmp_twitter gmpmp_sharelizer"><?php _e( 'Twitter', 'grand-media' ); ?></a></li>
											<li style="list-style:none;"><a class="gmpmp_button gmpmp_pinterest gmpmp_sharelizer"><?php _e( 'Pinterest', 'grand-media' ); ?></a></li>
											<li style="list-style:none;"><a class="gmpmp_button gmpmp_stumbleupon gmpmp_sharelizer"><?php _e( 'StumbleUpon', 'grand-media' ); ?></a></li>
										</ul>
									</div>
								</div>
							<?php } ?>
							<?php if ( $enable_counters && $show_like_button ) { ?>
								<a class="gmpmp_button gmpmp_like"><?php _e( 'Like', 'grand-media' ); ?></a>
							<?php } ?>
						</div>
					<?php } ?>
					<?php if ( ! empty( $allsettings['show_comments'] ) ) {
						if ( '' === $content['data'][ $iSlide ]['cc'] ) {
							$link_class = ' gmpmp_inactive';
							$link_href  = '';
						} else {
							$link_class = '';
							$link_href  = "href='{$content['data'][$iSlide]['post_link']}#comments' target='_blank'";
						}
						?>
						<div class="gmpmp_big_button_wrap">
							<a class="gmpmp_big_button gmpmp_comments_button<?php echo $link_class; ?>" <?php echo $link_href; ?>>
                                <span class="gmpmp_count_icon">
                                    <span class="gmpmp_comments_count"><?php echo $content['data'][ $iSlide ]['cc'] ?></span>
                                    <span class="gmpmp_comments_icon">
                                        <svg xmlns="http://www.w3.org/2000/svg" style="display: none;">
                                            <symbol id="icon-bubbles2" viewBox="0 0 1152 1024">
                                                <path class="path1" d="M480 0v0c265.096 0 480 173.914 480 388.448s-214.904 388.448-480 388.448c-25.458 0-50.446-1.62-74.834-4.71-103.106 102.694-222.172 121.108-341.166 123.814v-25.134c64.252-31.354 116-88.466 116-153.734 0-9.106-0.712-18.048-2.030-26.794-108.558-71.214-177.97-179.988-177.97-301.89 0-214.534 214.904-388.448 480-388.448zM996 870.686c0 55.942 36.314 104.898 92 131.772v21.542c-103.126-2.318-197.786-18.102-287.142-106.126-21.14 2.65-42.794 4.040-64.858 4.040-95.47 0-183.408-25.758-253.614-69.040 144.674-0.506 281.26-46.854 384.834-130.672 52.208-42.252 93.394-91.826 122.414-147.348 30.766-58.866 46.366-121.582 46.366-186.406 0-10.448-0.45-20.836-1.258-31.168 72.57 59.934 117.258 141.622 117.258 231.676 0 104.488-60.158 197.722-154.24 258.764-1.142 7.496-1.76 15.16-1.76 22.966z"></path>
                                            </symbol>
                                        </svg>
                                        <svg class="gmMosaic-svgicon">
                                            <use xlink:href="#icon-bubbles2"/>
                                        </svg>
                                    </span>
                                </span>
								<span class="gmpmp_label"><?php echo $allsettings['comments_button_text']; ?></span>
							</a>
						</div>
					<?php } ?>
					<?php if ( ! empty( $allsettings['show_download_button'] ) ) { ?>
						<div class="gmpmp_big_button_wrap">
							<a class="gmpmp_big_button gmpmp_download_button" href="<?php echo $content['data'][ $iSlide ]['download']; ?>" download="<?php echo esc_attr( $content['data'][ $iSlide ]['file'] ); ?>">
								<span class="gmpmp_icon"></span>
								<span class="gmpmp_label"><?php echo $allsettings['download_button_text']; ?></span>
							</a>
						</div>
					<?php } ?>
					<?php if ( ! empty( $allsettings['show_link_button'] ) ) {
						if ( empty( $content['data'][ $iSlide ]['link'] ) ) {
							$link_class = ' gmpmp_inactive';
							$link_href  = '';
						} else {
							$link_class = '';
							$link_href  = "href='{$content['data'][$iSlide]['link']}' target='{$content['data'][$iSlide]['link_target']}'";
						}
						?>
						<div class="gmpmp_big_button_wrap">
							<a class="gmpmp_big_button gmpmp_link_button<?php echo $link_class; ?>" <?php echo $link_href; ?>>
								<span class="gmpmp_icon"></span>
								<span class="gmpmp_label"><?php echo $allsettings['link_button_text']; ?></span>
							</a>
						</div>
					<?php } ?>
				</div>
			</div>
		</div>
		<div class="gmpmp_focus_close_full">
			<span><a class="gmpmp_button gmpmp_close"><?php _e( 'Close', 'grand-media' ); ?></a></span>
			<span><a class="gmpmp_button gmpmp_full"><?php _e( 'Full', 'grand-media' ); ?></a></span>
		</div>
		<div class="gmpmp_photo_details<?php if ( empty( $allsettings['show_details_tab'] ) || empty( $content['data'][ $iSlide ]['details'] ) ) {
			echo ' no-details-tab';
		}
		if ( empty( $allsettings['show_location_tab'] ) || empty( $content['data'][ $iSlide ]['location'] ) ) {
			echo ' no-location-tab';
		} ?>">
			<div class="gmpmp_wrapper gmpmp_clearfix">
				<div class="gmpmp_description_wrap<?php echo empty( $content['data'][ $iSlide ]['description'] ) ? ' empty-item-description' : ''; ?>">
					<?php if ( ! empty( $allsettings['show_description'] ) ) { ?>
						<?php if ( ! empty( $allsettings['description_title'] ) ) { ?>
							<div class="details_title"><?php echo $allsettings['description_title']; ?></div>
						<?php } ?>
						<div class="gmpmp_description_text_wrap">
							<div class="gmpmp_slide_description"><?php echo $content['data'][ $iSlide ]['description']; ?></div>
							<a class="gmpmp_show_more gmpmp_hidden"><?php _e( 'More', 'grand-media' ); ?></a>
						</div>
					<?php } ?>
					<?php if ( ! empty( $allsettings['show_tags'] ) ) { ?>
						<div class="gmpmp_tags"><?php
							foreach ( $content['data'][ $iSlide ]['tags'] as $tag_id ) {
								echo '<span class="gmpmp_tag"><a href="' . urldecode( $content['terms']['tags'][ $tag_id ]['url'] ) . '">#' . $content['terms']['tags'][ $tag_id ]['name'] . '</a></span>';
							}
							?></div>
					<?php } ?>
				</div>

				<div class="gmpmp_meta_data">
					<?php if ( ! empty( $allsettings['show_details_tab'] ) ) {
						$slide = $content['data'][ $iSlide ]; ?>
						<div class="gmpmp_details_section">
							<div class="details_title"><?php echo $allsettings['details_title']; ?></div>

							<div class="gmpmp_slide_details">
								<?php if ( ! empty( $allsettings['enable_counters'] ) ) { ?>
									<div class='gmpmp_badges'>
										<div class='gmpmp_badges__column'>
											<div class='gmpmp_badges__label'><?php echo $allsettings['views_text']; ?></div>
											<div class='gmpmp_badges__count'><?php echo $slide['meta']['views']; ?></div>
										</div>
										<?php if ( ! empty( $allsettings['show_like_button'] ) ) { ?>
											<div class='gmpmp_badges__column'>
												<div class='gmpmp_badges__label'><?php echo $allsettings['likes_text']; ?></div>
												<div class='gmpmp_badges__count gmpmp_like_count'><?php echo $slide['meta']['likes']; ?></div>
											</div>
										<?php } ?>
										<?php if ( ! empty( $allsettings['show_comments'] ) && ( '' !== $content['data'][ $iSlide ]['cc'] ) ) { ?>
											<div class='gmpmp_badges__column'>
												<div class='gmpmp_badges__label'><?php echo $allsettings['comments_text']; ?></div>
												<div class='gmpmp_badges__count gmpmp_comments_count'><?php echo $content['data'][ $iSlide ]['cc']; ?></div>
											</div>
										<?php } ?>
										<div class='gmpmp_clearfix'></div>
									</div>
								<?php } ?>
								<?php if ( ! empty( $slide['details']['model'] ) ) { ?>
									<div class='gmpmp_exif'>
										<div class='gmpmp_label gmpmp_exif_model'><?php echo $slide['details']['model']; ?></div>
										<?php if ( ! empty( $slide['details']['lens'] ) ) { ?>
											<div class='gmpmp_label_small gmpmp_exif_lens'><?php echo $slide['details']['lens']; ?></div>
										<?php }
										$camera_settings = array();
										foreach ( $slide['details']['camera_settings'] as $key => $value ) {
											$camera_settings[] = "<span class='gmpmp_exif_{$key}'>{$value}</span>";
										}
										if ( ! empty( $camera_settings ) ) { ?>
											<div class='gmpmp_label_small gmpmp_camera_settings'><?php echo implode( '<span class="gmpmp_separator"> / </span>', $camera_settings ); ?></div>
										<?php } ?>
									</div>
								<?php } ?>
								<div class='gmpmp_meta'>
									<?php if ( ! empty( $slide['details']['taken'] ) ) { ?>
										<div class='gmpmp_clearfix'>
											<span class='gmpmp_meta_key'><?php echo $allsettings['taken_text']; ?></span><span class='gmpmp_meta_value'><?php echo $slide['details']['taken']; ?></span>
										</div>
									<?php } ?>
									<div class='gmpmp_clearfix'>
										<span class='gmpmp_meta_key'><?php echo $allsettings['uploaded_text']; ?></span><span class='gmpmp_meta_value'><?php echo $slide['details']['uploaded']; ?></span>
									</div>
								</div>
							</div>
						</div>
					<?php } ?>
					<?php if ( ! empty( $allsettings['show_location_tab'] ) ) {
						$slide = $content['data'][ $iSlide ]; ?>
						<div class="gmpmp_location_section">
							<div class="details_title"><?php echo $allsettings['location_title']; ?></div>

							<div class="gmpmp_location_info"></div>
						</div>
					<?php } ?>
				</div>
			</div>
		</div>

		<div class="gmpmp_focus_footer">
			<div class="gmpmp_focus_keyboard">
				<div class="gmpmp_focus_keyboard_title"><?php _e( 'Keyboard Shortcuts', 'grand-media' ); ?> <a class="gmpmp_focus_keyboard_dismiss"><?php _e( 'Dismiss', 'grand-media' ); ?></a></div>
				<ul>
					<li style="list-style:none;"><a data-key="p" class="gmpmp_key">S</a><span class="gmpmp_label"><?php _e( 'Slideshow', 'grand-media' ); ?></span></li>
					<li style="list-style:none;"><a data-key="m" class="gmpmp_key">M</a><span class="gmpmp_label"><?php _e( 'Maximize', 'grand-media' ); ?></span></li>
					<li style="list-style:none;"><a data-key="left" class="gmpmp_key">&nbsp;</a><span class="gmpmp_label"><?php _e( 'Previous', 'grand-media' ); ?></span></li>
					<li style="list-style:none;"><a data-key="right" class="gmpmp_key">&nbsp;</a><span class="gmpmp_label"><?php _e( 'Next', 'grand-media' ); ?></span></li>
					<li style="list-style:none;"><a data-key="escape" class="gmpmp_key gmpmp_esc">esc</a><span class="gmpmp_label"><?php _e( 'Close', 'grand-media' ); ?></span></li>
				</ul>
			</div>
		</div>

	</div>

<?php if ( $shortcode_raw ) {
	echo '<pre style="display:none">';
}
?>
	<script type="text/javascript">
			document.addEventListener( 'DOMContentLoaded', function() {
				jQuery( function( $ ) {
					var settings = <?php echo json_encode( $settings ); ?>;
					var content = <?php echo json_encode( $content ); ?>;
					var container = $( '#GmediaGallery_<?php echo absint( $id ); ?>' );
					container.phototravlr( settings, content );
					window.GmediaGallery_<?php echo absint( $id ); ?> = container.data( 'phototravlr' );
				} );
			} );
	</script><?php if ( $shortcode_raw ) {
	echo '</pre>';
} ?>
<?php

$cssid     = "#GmediaGallery_{$id}";
$color_css = '';
if ( isset( $settings['menu_bg_color'] ) ) {
	$color_css .= "
{$cssid} .gmpmp_gallery_sources_menu .gmpmp_menu_bg {background-color:{$allsettings['menu_bg_color']};}";
}
if ( isset( $settings['menu_text_color'] ) ) {
	$color_css .= "
{$cssid} .gmpmp_gallery_sources_list {color:#{$settings['menu_text_color']};}";
}
if ( isset( $settings['menu_title_color'] ) ) {
	$color_css .= "
{$cssid} .gmpmp_gallery_sources_list .gmpmp_gallery_title {color:#{$settings['menu_title_color']};}";
}
if ( isset( $settings['menu_link_color'] ) ) {
	$color_css .= "
{$cssid} .gmpmp_gallery_sources_list a {color:#{$settings['menu_link_color']};}";
}
if ( isset( $settings['menu_link_color_hover'] ) ) {
	$color_css .= "
{$cssid} .gmpmp_gallery_sources_list a:hover {color:#{$settings['menu_link_color_hover']};}";
}
if ( isset( $settings['link_color'] ) ) {
	$color_css .= "
{$cssid} .gmpmp_gallery_sources_menu .gmpmp_menu_button:before,
{$cssid} .gmpmp_gallery_sources_menu .gmpmp_menu_button:after {border-color:#{$settings['link_color']};}
{$cssid} .gmpmp_photo_details .gmpmp_description_wrap .gmpmp_tags .gmpmp_tag a,
{$cssid} .gmpmp_big_button_wrap .gmpmp_button.gmpmp_like.gmpmp_liked,
{$cssid} .gmpmp_big_button_wrap .gmpmp_button.gmpmp_like.gmpmp_liked:hover,
{$cssid} div.gmpmp_tab_view div.gmpmp_tabs .gmpmp_tab.gmpmp_active {color:#{$settings['link_color']};}
{$cssid} .gmpmp_photo_show .gmpmp_big_button,
{$cssid} .gmpmp_photo_details .gmpmp_description_wrap a.gmpmp_show_more:hover {background-color:#{$settings['link_color']};}";
}
if ( isset( $settings['link_color_hover'] ) ) {
	$color_css .= "
{$cssid} .gmpmp_gallery_sources_menu .gmpmp_menu_button:hover:before,
{$cssid} .gmpmp_gallery_sources_menu .gmpmp_menu_button:hover:after,
{$cssid} .swiper-small-images div.gmpmp_photo.swiper-slide-active {border-color:#{$settings['link_color_hover']};}
{$cssid} .gmpmp_photo_header .gmpmp_name_wrap .gmpmp_title_author a:hover,
{$cssid} .gmpmp_photo_details .gmpmp_description_wrap .gmpmp_tags .gmpmp_tag a:hover,
{$cssid} div.gmpmp_tab_view div.gmpmp_tabs .gmpmp_tab:hover {color:#{$settings['link_color_hover']};}
{$cssid} .gmpmp_photo_show .gmpmp_big_button:hover,
{$cssid} .gmpmp_focus_actions ul .gmpmp_button.like.gmpmp_liked {background-color:#{$settings['link_color_hover']};}";
}

$gmpmp_css = "
{$cssid} .gmpmp_preload {opacity:0;}";
if ( 'fit' == $allsettings['scale_mode'] ) {
	$gmpmp_css .= "
{$cssid} .swiper-big-images img.gmpmp_the_photo { max-height:100%; max-width:100%; display:inline; width:auto; height:auto; object-fit:unset; vertical-align:middle; border:none; }";
} else {
	$gmpmp_css .= "
{$cssid} .swiper-big-images img.gmpmp_the_photo { max-height:100%; max-width:100%; display:inline; width:100%; height:100%; object-fit:cover; vertical-align:middle; border:none; }";
}
$gmpmp_css .= "
{$cssid} .gmpmp_focus .swiper-big-images img.gmpmp_the_photo { width:auto; height:auto; object-fit:unset; }
{$cssid} .swiper-small-images img.gmpmp_photo { max-width:none; max-height:none; }
{$cssid} .swiper-small-images img.gmpmp_photo.gmpmp_photo_landscape { width:auto; height:100%; }
{$cssid} .swiper-small-images img.gmpmp_photo.gmpmp_photo_portrait { width:100%; height:auto; }
{$cssid} .gmpmp_gallery_sources_list p { margin:7px 0; padding:0; font-size:inherit; }";
$customCSS = $gmpmp_css . $color_css . $customCSS;
